from dataclasses import dataclass
from typing import List, Mapping
from bs4 import BeautifulSoup
import json
from requests import Response as R
import logging

logger = logging.getLogger()

@dataclass
class Response:
    """[summary]
    """
    headers: Mapping[str, str]
    content: str
    response: R

@dataclass
class ResponseHtml:
    """[summary]
    """
    headers: Mapping[str, str]
    content: BeautifulSoup
    response: R

@dataclass
class ResponseJson:
    """[summary]
    """
    headers: Mapping[str, str]
    content:  json
    response: R


import unittest
from catswalk.scraping.request import CWRequest


class TestCWRequest(unittest.TestCase):
    def test_get(self):
        """[python -m unittest tests.scraping.test_request.TestCWRequest.test_get]
        """
        #request = CWRequest()
        #responseHtml = request.get(url="https://yahoo.co.jp", response_content_type="html")
        #print(responseHtml)
        #request.close()
        with CWRequest() as request:
            responseHtml = request.get(url="https://yahoo.co.jp", response_content_type="html")
            print(responseHtml)
        

if __name__ == "__main__":
    unittest.main()


import asyncio
import aiohttp
from bs4 import BeautifulSoup
import logging

logger = logging.getLogger()


async def async_get(url, session):
    try:
        async with session.get(url=url) as response:
            resp = await response.read()
            logging.info("Successfully got url {} with resp of length {}.".format(url, len(resp)))
            soup = BeautifulSoup(resp, features="html.parser")
            return soup
    except Exception as e:
        logging.error("Unable to get url {} due to {}.".format(url, e.__class__))


async def async_gets(url_list):
    async with aiohttp.ClientSession() as session:
        ret = await asyncio.gather(*[async_get(url, session) for url in url_list])
    logging.info("Finalized all. Return is a list of len {} outputs.".format(len(ret)))
    return ret


class AsyncCWRequest:
    @classmethod
    def execute(self, url_list):
        return asyncio.run(async_gets(url_list))


import asyncio
import aiohttp
import time
from bs4 import BeautifulSoup
from catswalk.scraping.async_request import  AsyncCWRequest

url_list = ["https://www.youtube.com", "https://www.facebook.com", "https://www.baidu.com"]

AsyncCWRequest.execute(url_list)


import asyncio
import aiohttp
import time
from bs4 import BeautifulSoup

websites = """https://www.youtube.com
https://www.facebook.com
https://www.baidu.com
"""


async def async_get(url, session):
    try:
        async with session.get(url=url) as response:
            resp = await response.read()
            print("Successfully got url {} with resp of length {}.".format(url, len(resp)))
            soup = BeautifulSoup(resp, features="html.parser")
            return soup
    except Exception as e:
        print("Unable to get url {} due to {}.".format(url, e.__class__))


async def async_gets(urls):
    async with aiohttp.ClientSession() as session:
        ret = await asyncio.gather(*[async_get(url, session) for url in urls])
    print(ret)
    print("Finalized all. Return is a list of len {} outputs.".format(len(ret)))


urls = websites.split("\n")
start = time.time()
asyncio.run(async_gets(urls))
end = time.time()

print("Took {} seconds to pull {} websites.".format(end - start, len(urls)))